@@ -23,17 +23,10 @@ athena_read.athena_data.table <-
 athena_read.athena_vroom <- 
   function(method, File, athena_types, ...){
     vroom <- pkg_method("vroom", "vroom")
-    as.integer64 <- pkg_method("as.integer64", "bit64")
-    Type2 <- Type <- AthenaToRDataType(method, athena_types)
-    
-    # Type2 is to bigint
-    Type2[Type2 %in% "I"] <- "n"
-    
-    output <- vroom(File, delim = ",", col_types = Type2, progress = FALSE,trim_ws = FALSE, altrep_opts = TRUE)
-    
-    # convert numeric class to integer64 to match athena's bigint
-    for (var in names(Type[Type %in% "I"])) output[[var]] <- as.integer64(output[[var]])
-    
+    Type <- AthenaToRDataType(method, athena_types)
+
+    output <- vroom(File, delim = ",", col_types = Type, progress = FALSE, trim_ws = FALSE, altrep = TRUE)
+
     output
   }
 
